OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "La operación dada no es valida",
    "The given regular expression is invalid" : "La expresión regular dada no es valida",
    "The given file size is invalid" : "El tamaño del archivo dado no es válido ",
    "The given tag id is invalid" : "El id de etiqueta dado no es valido",
    "The given IP range is invalid" : "El rango de IPs no es valido",
    "The given IP range is not valid for IPv4" : "El rango de IP no es valida para IPv4",
    "The given IP range is not valid for IPv6" : "El rango de IP no es valida para IPv6",
    "The given time span is invalid" : "El intervalo temporal dado es inválido",
    "The given start time is invalid" : "La hora de inicio dada no es válida",
    "The given end time is invalid" : "El tiempo final no es valido",
    "The given group does not exist" : "El grupo dado no existe",
    "File" : "Archivo",
    "File created" : "Archivo creado",
    "File updated" : "Archivo actualizado",
    "File renamed" : "Archivo renombrado",
    "File deleted" : "Archivo eliminado",
    "File accessed" : "Archivo accedido",
    "File copied" : "Archivo copiado",
    "Tag assigned" : "Etiqueta asignada",
    "Someone" : "Alguien",
    "%s created %s" : "%s ha creado %s",
    "%s modified %s" : "%s ha modificado %s",
    "%s deleted %s" : "%s ha eliminado %s",
    "%s accessed %s" : "%s ha accedido a %s",
    "%s renamed %s" : "%s ha renombrado %s",
    "%s copied %s" : "%s ha copiado %s",
    "%s assigned %s to %s" : "%s ha asignado %s a %s",
    "Operation #%s does not exist" : "Operación #%s no existe",
    "Entity %s does not exist" : "Entidad %s no existe",
    "Entity %s is invalid" : "La entidad %s no es valida",
    "No events are chosen." : "No se ha elegido ningún evento.",
    "Entity %s has no event %s" : "La entidad %s no tiene eventos %s",
    "Operation %s does not exist" : "Operación %s no existe",
    "Operation %s is invalid" : "Operación %s no es valida",
    "At least one check needs to be provided" : "Has de seleccionar al menos una comprobación",
    "The provided operation data is too long" : "Los datos de la operación son demasiado largos",
    "Invalid check provided" : "La comprobación proporcionada no es válida",
    "Check %s does not exist" : "La comprobación %s no existe",
    "Check %s is invalid" : "La comprobación %s no es válida",
    "Check %s is not allowed with this entity" : "La comprobación %s no se permite con esta entidad",
    "The provided check value is too long" : "El valor de la comprobación es demasiado grande",
    "Check #%s does not exist" : "El chequeo #%s no existe",
    "Check %s is invalid or does not exist" : "Comprueba %s no es valido o no existe",
    "Flow" : "Flujo",
    "Nextcloud workflow engine" : "Motor de flujo de trabajo de Nextcloud",
    "Select a filter" : "Seleccione un filtro",
    "Select a comparator" : "Seleccione un comparador",
    "Remove filter" : "Quitar filtro",
    "Audio" : "Audio",
    "Folder" : "Carpeta",
    "Images" : "Imágenes",
    "Office documents" : "Documentos de oficina",
    "PDF documents" : "Documentos PDF",
    "Video" : "Vídeo",
    "Custom MIME type" : "Tipo MIME personalizado",
    "Custom mimetype" : "Tipo MIME (mimetype) personalizado",
    "Select a file type" : "Selecciona un tipo de archivo",
    "e.g. httpd/unix-directory" : "p.ej.: httpd/carpeta-unix",
    "Please enter a valid time span" : "Por favor especifique un intervalo de tiempo válido",
    "Files WebDAV" : "Archivos WebDAV",
    "Custom URL" : "URL personalizada",
    "Select a request URL" : "Selecciona una URL de petición",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Thunderbird & Outlook addons" : "Complementos de Thunderbird y Outlook",
    "Custom user agent" : "Agente de usuario personalizado",
    "Select a user agent" : "Selecciona un agente de usuario",
    "Select groups" : "Seleccionar grupos",
    "Groups" : "Grupos",
    "Type to search for group …" : "Teclee para buscar un grupo …",
    "Select a trigger" : "Seleccione un disparador",
    "At least one event must be selected" : "Has de seleccionar al menos un evento",
    "Add new flow" : "Añadir nuevo flujo",
    "The configuration is invalid" : "La configuración es incorrecta",
    "Active" : "Activo",
    "Save" : "Guardar",
    "When" : "Cuando",
    "and" : "y",
    "Add a new filter" : "Añadir un nuevo filtro",
    "Cancel" : "Cancelar",
    "Delete" : "Eliminar",
    "Available flows" : "Flujos disponibles",
    "For details on how to write your own flow, check out the development documentation." : "Para detalles acerca de cómo escribir su propio flujo, mire la documentación dedesarrollo.",
    "No flows installed" : "No hay flujos instalados",
    "Ask your administrator to install new flows." : "Pida a su administrador instalar nuevos flujos.",
    "More flows" : "Más flujos",
    "Browse the App Store" : "Explorar la App Store",
    "Show less" : "Ver menos",
    "Show more" : "Ver más",
    "Configured flows" : "Configurar flujos",
    "Your flows" : "Sus flujos",
    "No flows configured" : "No hay flujos configurados",
    "matches" : "coincidencias",
    "does not match" : "no coincide",
    "is" : "es/esta",
    "is not" : "no es/esta",
    "File name" : "Nombre del archivo",
    "File MIME type" : "Tipo MIME del archivo",
    "File size (upload)" : "Tamaño del archivo (para subir)",
    "less" : "menos",
    "less or equals" : "menor o igual",
    "greater or equals" : "mayor o igual",
    "greater" : "mayor",
    "Request remote address" : "Solicitar dirección remota",
    "matches IPv4" : "IPv4 coincidencias",
    "does not match IPv4" : "IPv4 sin coincidencias",
    "matches IPv6" : "IPv6 coincidencias",
    "does not match IPv6" : "IPv6 sin coincidencias",
    "File system tag" : "Etiqueta de archivo de sistema",
    "is tagged with" : "esta etiquetado con",
    "is not tagged with" : "no esta etiquetado con",
    "Request URL" : "URL de solicitud",
    "Request time" : "Tiempo de espera",
    "between" : "entre",
    "not between" : "no entre",
    "Request user agent" : "Solicitud del agente usuario ",
    "Group membership" : "Membresía a grupos",
    "is member of" : "es miembro de",
    "is not member of" : "no es miembro de"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
